@@ -52,15 +52,13 @@
 #include <iostream>
 #include <sstream>
 
-using namespace std;
-
 namespace breakfastquay
 {
 
-static vector<string>
+static std::vector<std::string>
 getCoreAudioWriteExtensions()
 {
-    vector<string> extensions;
+    std::vector<std::string> extensions;
     extensions.push_back("m4a");
     return extensions;
 }
@@ -68,7 +66,7 @@ getCoreAudioWriteExtensions()
 static 
 AudioWriteStreamBuilder<CoreAudioWriteStream>
 coreaudiowritebuilder(
-    string("http://breakfastquay.com/rdf/turbot/audiostream/CoreAudioWriteStream"),
+    std::string("http://breakfastquay.com/rdf/turbot/audiostream/CoreAudioWriteStream"),
     getCoreAudioWriteExtensions()
     );
 
@@ -83,7 +81,7 @@ public:
     OSStatus                     err; 
 };
 
-static string
+static std::string
 codestr(OSStatus err)
 {
     char text[5];
@@ -93,7 +91,7 @@ codestr(OSStatus err)
     text[2] = (uerr >> 8) & 0xff;
     text[3] = (uerr) & 0xff;
     text[4] = '\0';
-    ostringstream os;
+    std::ostringstream os;
     os << err << " (" << text << ")";
     return os.str();
 }
@@ -102,7 +100,7 @@ CoreAudioWriteStream::CoreAudioWriteStream(Target target) :
     AudioWriteStream(target),
     m_d(new D)
 {
-    cerr << "CoreAudioWriteStream: file is " << getPath() << ", channel count is " << getChannelCount() << ", sample rate " << getSampleRate() << endl;
+//    cerr << "CoreAudioWriteStream: file is " << getPath() << ", channel count is " << getChannelCount() << ", sample rate " << getSampleRate() << endl;
 
     UInt32 propsize = sizeof(AudioStreamBasicDescription);
 
@@ -114,7 +112,7 @@ CoreAudioWriteStream::CoreAudioWriteStream(Target target) :
                                       &propsize, &m_d->asbd);
 
 
-    string path = getPath();
+    std::string path = getPath();
     CFURLRef url = CFURLCreateFromFileSystemRepresentation
         (kCFAllocatorDefault,
          (const UInt8 *)path.c_str(),
@@ -135,7 +133,7 @@ CoreAudioWriteStream::CoreAudioWriteStream(Target target) :
 
     if (m_d->err) {
         m_error = "CoreAudioWriteStream: Failed to create file: code " + codestr(m_d->err);
-        cerr << m_error << endl;
+//        cerr << m_error << endl;
         throw FailedToWriteFile(getPath());
     }
 
@@ -167,7 +165,7 @@ CoreAudioWriteStream::CoreAudioWriteStream(Target target) :
     
     if (m_d->err) {
         m_error = "CoreAudioWriteStream: Error in setting client format: code " + codestr(m_d->err);
-        cerr << m_error << endl;
+//        cerr << m_error << endl;
 	ExtAudioFileDispose(m_d->file);
         throw FileOperationFailed(getPath(), "set client format");
     }
@@ -177,7 +175,7 @@ CoreAudioWriteStream::CoreAudioWriteStream(Target target) :
     
     if (m_d->err) {
         m_error = "CoreAudioWriteStream: Error in initialising file writes: code " + codestr(m_d->err);
-        cerr << m_error << endl;
+//        cerr << m_error << endl;
 	ExtAudioFileDispose(m_d->file);
         throw FileOperationFailed(getPath(), "initialise file writes");
     }
@@ -191,7 +189,7 @@ CoreAudioWriteStream::CoreAudioWriteStream(Target target) :
 CoreAudioWriteStream::~CoreAudioWriteStream()
 {
     if (m_d->file) {
-        cerr << "CoreAudioWriteStream::~CoreAudioWriteStream: disposing" << endl;
+//        cerr << "CoreAudioWriteStream::~CoreAudioWriteStream: disposing" << endl;
 	ExtAudioFileDispose(m_d->file);
     }
 }
@@ -211,7 +209,7 @@ CoreAudioWriteStream::putInterleavedFrames(size_t count, const float *frames)
     m_d->err = ExtAudioFileWrite(m_d->file, framesToWrite, &m_d->buffer);
     if (m_d->err) {
         m_error = "CoreAudioWriteStream: Error in encoder: code " + codestr(m_d->err);
-        cerr << m_error << endl;
+//        cerr << m_error << endl;
         throw FileOperationFailed(getPath(), "encode");
     }
 }
