@@ -6,7 +6,7 @@
     A small library for vector arithmetic and allocation in C++ using
     raw C pointer arrays.
 
-    Copyright 2007-2016 Particular Programs Ltd.
+    Copyright 2007-2021 Particular Programs Ltd.
 
     Permission is hereby granted, free of charge, to any person
     obtaining a copy of this software and associated documentation
@@ -174,6 +174,28 @@ inline void c_multiply_and_add(bq_complex_t &srcdst,
     c_add(srcdst, tmp);
 }
 
+inline void c_divide(bq_complex_t &dst,
+                     const bq_complex_t &src1,
+                     const bq_complex_t &src2)
+{
+    bq_complex_element_t scale = bq_complex_element_t
+        (1.0 / (src2.re * src2.re + src2.im * src2.im));
+
+    bq_complex_element_t real =
+        scale * (src1.re * src2.re + src1.im * src2.im);
+    bq_complex_element_t imag =
+        scale * (src1.im * src2.re - src1.re * src2.im);
+
+    dst.re = real;
+    dst.im = imag;
+}
+
+inline void c_divide(bq_complex_t &srcdst,
+                     const bq_complex_t &src)
+{
+    c_divide(srcdst, srcdst, src);
+}
+
 template<>
 inline void v_add(bq_complex_t *const BQ_R__ srcdst,
                   const bq_complex_t *const BQ_R__ src,
@@ -210,7 +232,7 @@ inline void v_multiply(bq_complex_t *const BQ_R__ srcdst,
                        const bq_complex_t *const BQ_R__ src,
                        const int count)
 {
-#ifdef HAVE_IPP
+#if defined HAVE_IPP
     if (sizeof(bq_complex_element_t) == sizeof(float)) {
         ippsMul_32fc_I((const Ipp32fc *)src, (Ipp32fc *)srcdst, count);
     } else {
@@ -229,7 +251,7 @@ inline void v_multiply_to(bq_complex_t *const BQ_R__ dst,
                           const bq_complex_t *const BQ_R__ src2,
                           const int count)
 {
-#ifdef HAVE_IPP
+#if defined HAVE_IPP
     if (sizeof(bq_complex_element_t) == sizeof(float)) {
         ippsMul_32fc((const Ipp32fc *)src1, (const Ipp32fc *)src2,
                      (Ipp32fc *)dst, count);
@@ -237,20 +259,99 @@ inline void v_multiply_to(bq_complex_t *const BQ_R__ dst,
         ippsMul_64fc((const Ipp64fc *)src1, (const Ipp64fc *)src2,
                      (Ipp64fc *)dst, count);
     }
+#elif defined HAVE_VDSP
+    if (sizeof(bq_complex_element_t) == sizeof(float)) {
+        DSPSplitComplex sdst, ssrc1, ssrc2;
+        sdst.realp = (float *)dst;
+        sdst.imagp = sdst.realp + 1;
+        ssrc1.realp = (float *)src1;
+        ssrc1.imagp = ssrc1.realp + 1;
+        ssrc2.realp = (float *)src2;
+        ssrc2.imagp = ssrc2.realp + 1;
+        vDSP_zvmul(&ssrc1, 2, &ssrc2, 2, &sdst, 2, count, 1);
+    } else {
+        DSPDoubleSplitComplex sdst, ssrc1, ssrc2;
+        sdst.realp = (double *)dst;
+        sdst.imagp = sdst.realp + 1;
+        ssrc1.realp = (double *)src1;
+        ssrc1.imagp = ssrc1.realp + 1;
+        ssrc2.realp = (double *)src2;
+        ssrc2.imagp = ssrc2.realp + 1;
+        vDSP_zvmulD(&ssrc1, 2, &ssrc2, 2, &sdst, 2, count, 1);
+    }
 #else
     for (int i = 0; i < count; ++i) {
         c_multiply(dst[i], src1[i], src2[i]);
     }
+#endif
+}
+
+template<>
+inline void v_divide(bq_complex_t *const BQ_R__ srcdst,
+                     const bq_complex_t *const BQ_R__ src,
+                     const int count)
+{
+#if defined HAVE_IPP
+    if (sizeof(bq_complex_element_t) == sizeof(float)) {
+        ippsDiv_32fc_I((const Ipp32fc *)src, (Ipp32fc *)srcdst, count);
+    } else {
+        ippsDiv_64fc_I((const Ipp64fc *)src, (Ipp64fc *)srcdst, count);
+    }
+#else
+    for (int i = 0; i < count; ++i) {
+        c_divide(srcdst[i], src[i]);
+    }
 #endif // HAVE_IPP
 }
 
+template<>
+inline void v_divide_to(bq_complex_t *const BQ_R__ dst,
+                        const bq_complex_t *const BQ_R__ src1,
+                        const bq_complex_t *const BQ_R__ src2,
+                        const int count)
+{
+#if defined HAVE_IPP
+    if (sizeof(bq_complex_element_t) == sizeof(float)) {
+        ippsDiv_32fc((const Ipp32fc *)src2, (const Ipp32fc *)src1,
+                     (Ipp32fc *)dst, count);
+    } else {
+        ippsDiv_64fc((const Ipp64fc *)src2, (const Ipp64fc *)src1,
+                     (Ipp64fc *)dst, count);
+    }
+#elif defined HAVE_VDSP
+    if (sizeof(bq_complex_element_t) == sizeof(float)) {
+        DSPSplitComplex sdst, ssrc1, ssrc2;
+        sdst.realp = (float *)dst;
+        sdst.imagp = sdst.realp + 1;
+        ssrc1.realp = (float *)src1;
+        ssrc1.imagp = ssrc1.realp + 1;
+        ssrc2.realp = (float *)src2;
+        ssrc2.imagp = ssrc2.realp + 1;
+        vDSP_zvdiv(&ssrc2, 2, &ssrc1, 2, &sdst, 2, count);
+    } else {
+        DSPDoubleSplitComplex sdst, ssrc1, ssrc2;
+        sdst.realp = (double *)dst;
+        sdst.imagp = sdst.realp + 1;
+        ssrc1.realp = (double *)src1;
+        ssrc1.imagp = ssrc1.realp + 1;
+        ssrc2.realp = (double *)src2;
+        ssrc2.imagp = ssrc2.realp + 1;
+        vDSP_zvdivD(&ssrc2, 2, &ssrc1, 2, &sdst, 2, count);
+    }
+#else
+    for (int i = 0; i < count; ++i) {
+        c_divide(dst[i], src1[i], src2[i]);
+    }
+#endif
+}
+
 template<>
 inline void v_multiply_and_add(bq_complex_t *const BQ_R__ srcdst,
                                const bq_complex_t *const BQ_R__ src1,
                                const bq_complex_t *const BQ_R__ src2,
                                const int count)
 {
-#ifdef HAVE_IPP
+#if defined HAVE_IPP
     if (sizeof(bq_complex_element_t) == sizeof(float)) {
         ippsAddProduct_32fc((const Ipp32fc *)src1, (const Ipp32fc *)src2,
                             (Ipp32fc *)srcdst, count);
@@ -265,27 +366,55 @@ inline void v_multiply_and_add(bq_complex_t *const BQ_R__ srcdst,
 #endif // HAVE_IPP
 }
 
-#if defined( __GNUC__ ) && defined( _WIN32 )
-// MinGW doesn't appear to have sincos, so define it -- it's
-// a single x87 instruction anyway
-static inline void sincos(double x, double *sin, double *cos) {
-    __asm__ ("fsincos;" : "=t" (*cos), "=u" (*sin) : "0" (x) : "st(7)");
-}
-static inline void sincosf(float fx, float *fsin, float *fcos) {
-    double sin, cos;
-    sincos(fx, &sin, &cos);
-    *fsin = sin;
-    *fcos = cos;
-}
+template<>
+inline bq_complex_t v_multiply_and_sum(const bq_complex_t *const BQ_R__ src1,
+                                       const bq_complex_t *const BQ_R__ src2,
+                                       const int count)
+{
+    bq_complex_t result = bq_complex_t();
+#if defined HAVE_IPP
+    if (sizeof(bq_complex_element_t) == sizeof(float)) {
+        ippsDotProd_32fc((const Ipp32fc *)src1, (const Ipp32fc *)src2,
+                         count, (Ipp32fc *)&result);
+    } else {
+        ippsDotProd_64fc((const Ipp64fc *)src1, (const Ipp64fc *)src2,
+                         count, (Ipp64fc *)&result);
+    }
+#elif defined HAVE_VDSP
+    if (sizeof(bq_complex_element_t) == sizeof(float)) {
+        DSPSplitComplex sdst, ssrc1, ssrc2;
+        sdst.realp = (float *)&result;
+        sdst.imagp = sdst.realp + 1;
+        ssrc1.realp = (float *)src1;
+        ssrc1.imagp = ssrc1.realp + 1;
+        ssrc2.realp = (float *)src2;
+        ssrc2.imagp = ssrc2.realp + 1;
+        vDSP_zdotpr(&ssrc1, 2, &ssrc2, 2, &sdst, count);
+    } else {
+        DSPDoubleSplitComplex sdst, ssrc1, ssrc2;
+        sdst.realp = (double *)&result;
+        sdst.imagp = sdst.realp + 1;
+        ssrc1.realp = (double *)src1;
+        ssrc1.imagp = ssrc1.realp + 1;
+        ssrc2.realp = (double *)src2;
+        ssrc2.imagp = ssrc2.realp + 1;
+        vDSP_zdotprD(&ssrc1, 2, &ssrc2, 2, &sdst, count);
+    }
+#else
+    bq_complex_t out = bq_complex_t();
+    for (int i = 0; i < count; ++i) {
+        c_multiply(out, src1[i], src2[i]);
+        c_add(result, out);
+    }
 #endif
+    return result;
+}
 
 #endif // !NO_COMPLEX_TYPES
 
 template<typename T>
 inline void c_phasor(T *real, T *imag, T phase)
 {
-    //!!! IPP contains ippsSinCos_xxx in ippvm.h -- these are
-    //!!! fixed-accuracy, test and compare
 #if defined HAVE_VDSP
     int one = 1;
     if (sizeof(T) == sizeof(float)) {
@@ -329,7 +458,7 @@ inline void c_magphase(T *mag, T *phase, T real, T imag)
     *phase = atan2(imag, real);
 }
 
-#ifdef USE_APPROXIMATE_ATAN2
+#if defined USE_APPROXIMATE_ATAN2
 // NB arguments in opposite order from usual for atan2f
 extern float approximate_atan2f(float real, float imag);
 template<>
@@ -437,7 +566,7 @@ void v_polar_to_cartesian_interleaved(T *const BQ_R__ dst,
     }
 }    
 
-#ifdef HAVE_IPP
+#if defined HAVE_IPP
 template<>
 inline void v_polar_to_cartesian(float *const BQ_R__ real,
                                  float *const BQ_R__ imag,
@@ -540,7 +669,7 @@ void v_cartesian_interleaved_to_polar(T *const BQ_R__ mag,
     }
 }
 
-#ifdef HAVE_IPP
+#if defined HAVE_IPP
 
 template<>
 inline void v_cartesian_to_polar(float *const BQ_R__ mag,
@@ -647,7 +776,7 @@ void v_cartesian_interleaved_to_magnitudes(T *const BQ_R__ mag,
     }
 }
 
-#ifdef HAVE_IPP
+#if defined HAVE_IPP
 template<>
 inline void v_cartesian_to_magnitudes(float *const BQ_R__ mag,
                                       const float *const BQ_R__ real,
